.. include:: ../README.rst

.. toctree::
   :maxdepth: 3

   use.rst
   mapping.rst
   patterns.rst
   parsers.rst
   api.rst
   development.rst
   changes.rst
   license.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

